function [sys,x0,str,ts] = circulo2(t,x,u,flag,Ts)

global UI_Frot UI_t_Frot UI_STOP phi0 hndlList N

switch flag,
  %%%%%%%%%%%%%%%%%%
  % Initialization %
  %%%%%%%%%%%%%%%%%%
  % Initialize the states, sample times, and state ordering strings.
  case 0
    sizes = simsizes;
    sizes.NumContStates  = 0;
    sizes.NumDiscStates  = 0;
    sizes.NumOutputs     = 1; 
    sizes.NumInputs      = 1; 
    sizes.DirFeedthrough = 1;   % has direct feedthrough
    sizes.NumSampleTimes = 1;

    sys = simsizes(sizes);
    str = [];
    x0  = [];
    ts  = [-1 0];   % inherited sample time

    %disenio del circulo exterior
    k = (0:0.01:1)'*2*pi;
    xc = sin(k);
    yc = cos(k);
    
    %disenio vectores de los radios del circulo
    N=1;
    phi0=[0:1:N-1]'/N*2*pi;
    xr=zeros(N*2,1);
    yr=zeros(N*2,1);
    xr(2:2:N*2)= sin(phi0);
    yr(2:2:N*2)= cos(phi0);
   
    %Grafica inicial
    animinit('Efecto Estroboscopico - Aliasing - TeSyS 2005');
    fill(xc,yc,'w','LineStyle','none');
    hold on
    hndlList=plot(xr,yr,'LineWidth',8);
    texto=sprintf('F_s = %d Hz  (Rotacion en sentido horario)', round(1/Ts));
    title(texto,'FontSize',14)
    hold off
    axis square
    axis off

    %Slider de la frecuencia de rotacion
    UI_Frot=uicontrol(...
         'Style','slider',...
         'Units','normalized', ...
  	 	 'Position',[.76 .8 .23 .05],...
  	 	 'Min',0,...
         'Max',100,...
         'SliderStep',[0.01 0.05],...   
         'Value',round(1/Ts)*0);
     
    texto = sprintf('Frot = %d rps', get(UI_Frot,'Value'));
    
    UI_t_Frot = uicontrol(...
         'Style','text',...
         'Units','normalized', ...
  	 	 'Position',[.79 .87 .17 .05],...
         'String',texto,...
         'FontSize',14, ...
         'BackgroundColor',[0.75 .75 0.75]);
    
     %Boton de STOP
  	  UI_STOP=uicontrol( ...
       'Style','checkbox', ...
       'Units','normalized', ...
       'Position',[.8 .05 .15 .1], ...
       'String','Inicio', ...
       'BackgroundColor',[0.75 .75 0.75]);

      UI_N = uicontrol( ...
       'style','edit', ...
       'Units','normalized', ...
       'Position',[.1 .81 .09 .06], ...
       'String',num2str(N), ...
       'BackgroundColor',[0.9 .9 0.9], ...
       'FontSize', 15);

     UI_Nt = uicontrol( ...
       'style','text', ...
       'Units','normalized', ...
       'Position',[.05 .8 .05 .05], ...
       'String','N =', ...
       'BackgroundColor',[0.75 .75 0.75], ...
       'FontSize', 15);
      
    while get(UI_STOP,'Value')==0
        pause(.1 )
        N = str2num(get(UI_N,'String'));
        
        if N~=1
            phi0=[0:1:N-1]'/N*2*pi;
            xr=zeros(N*2,1);
            yr=zeros(N*2,1);
            xr(2:2:N*2)= sin(phi0);
            yr(2:2:N*2)= cos(phi0);

            delete(hndlList)
            hold on
            hndlList=plot(xr,yr,'LineWidth',8);
            hold off    
        end
    end
    set(UI_STOP,'String','Terminar') 
    set(UI_N,'Enable','off')

  %%%%%%%%%%%
  % Outputs %
  %%%%%%%%%%%
  % Return the outputs of the S-function block.
  case 3
    
    f1=round(get(UI_Frot,'Value'));
    texto = sprintf('Frot = %d rps', round(f1));
    set(UI_t_Frot,'String',texto)
      
    xr(2:2:N*2)= sin(2*pi*f1*t + phi0);
    yr(2:2:N*2)= cos(2*pi*f1*t + phi0);
    
    set(hndlList,'XData',xr)
    set(hndlList,'YData',yr)
    
    
    sys=-get(UI_STOP,'Value')+1 ;
    pause(Ts*5)
    
  %%%%%%%%%%%%%%%%%%%%%%%
  % GetTimeOfNextVarHit %
  %%%%%%%%%%%%%%%%%%%%%%%
  case 4,

    sys = t + Ts;
   

  %%%%%%%%%%%%%%%%%%%
  % Unhandled flags %
  %%%%%%%%%%%%%%%%%%%
  % There are no termination tasks (flag=9) to be handled.
  % Also, there are no continuous or discrete states,
  % so flags 1,2, and 4 are not used, so return an emptyu
  % matrix 
  case { 1, 2, 9 }
    sys=[];

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % Unexpected flags (error handling)%
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % Return an error message for unhandled flag values.
  otherwise
    error(['Unhandled flag = ',num2str(flag)]);

end
